from io import BytesIO

from phylodata.parsers.parse_trees import parse_trees


def to_bytes_io(text: str):
    bytesio = BytesIO(bytes(text, "ascii"))
    bytesio.name = "Test"
    return bytesio


def test_parse_trees():
    raw_nexus = """
    #NEXUS
    Begin taxa;
       	Dimensions ntax=3;
  		Taxlabels
 			0
 			1
            2;
    End;
    Begin trees;
        tree STATE_1 = ((0: 1.5, 1: 1.5): 2.0, 2: 3.5):0.5;
        tree STATE_2 = ((0: 1.5, 1: 1.5): 2.0, 2: 3.5):0.5;
        tree STATE_3 = ((0: 1.5, 1: 1.5): 2.0, 2: 3.5):0.5;
        tree STATE_4 = ((0: 1.5, 1: 1.5): 2.0, 2: 3.5):0.5;
    End;
    """

    file = to_bytes_io(raw_nexus)
    parsed = parse_trees(file)

    assert parsed.number_of_trees == 4
    assert parsed.number_of_tips == 3
    assert parsed.time_tree
    assert parsed.ultrametric
    assert parsed.rooted
    assert parsed.average_root_age == 3.5



from io import BytesIO

import pytest

from phylodata.errors import ValidationError
from phylodata.parsers.parse_files import parse_beast2_logs


def to_bytes_io(text: str):
    bytesio = BytesIO(bytes(text, "ascii"))
    bytesio.name = "Test"
    return bytesio


def test_simple_log_is_ok():
    raw_logs = "state   posterior"
    for s in range(1000):
        raw_logs += f"\n{s}   0"

    file = to_bytes_io(raw_logs)
    parse_beast2_logs(file)


def test_log_file_with_few_lines_fails():
    with pytest.raises(ValidationError):
        raw_logs = "state   posterior"
        for s in range(5):
            raw_logs += f"\n{s} 0"

        file = to_bytes_io(raw_logs)
        parse_beast2_logs(file)


def test_empty_file_fails():
    with pytest.raises(ValidationError):
        file = to_bytes_io("")
        parse_beast2_logs(file)


def test_no_tsv_fails():
    with pytest.raises(ValidationError):
        file = to_bytes_io("""This is some random file:khklhdsf
            asdfsadfsadf""")
        parse_beast2_logs(file)



import click
import subprocess
from phylodata.data_types import validate_json, get_schema


@click.group()
def phylodata(): ...


@phylodata.command(help="Process an experiment before uploading it to PhyloData.")
def process():
    subprocess.Popen(["streamlit", "run", "phylodata/ui.py"])


@phylodata.command(
    help="Validate if a given JSON file contains valid PhyloData metadata."
)
@click.argument("file_path", type=click.Path(exists=True))
def validate(file_path: str):
    validate_json(file_path)
    print("File is valid!")


@phylodata.command(help="Prints the JSON schema for valid PhyloData metadata files.")
def schema():
    print(get_schema())
